CodeConfigBuilder

Struct CodeConfigBuilder 

pub struct CodeConfigBuilder { /* private fields */ }
Builder for CodeConfig.

Implementations

Source

impl CodeConfigBuilder

pub fn font_family<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn breadcrumbs<VALUE: Into<Breadcrumbs>>( &mut self, value: VALUE, ) -> &mut Self

Breadcrumbs is a useful and unique feature of CodeSnap, it can help users to understand the code location in the project. If the has_breadcrumbs is true, CodeSnap will display the file_path on top of the code.

The code snapshot is different from normal screenshots, it should provide more information about the code, such as the file path, the line number and highlight code line, these information can help users to understand the code better.

pub fn build(&self) -> Result<CodeConfig, CodeConfigBuilderError>

Builds a new CodeConfig.

Errors

If a required field has not been initialized.